const Request = require('./Request');

module.exports = {
    Tenor: class Tenor {
        constructor(tenorApiKey) {
            this.token = tenorApiKey;
        }

        async configure() {
            // Sanity tests
            if (!this.token) {
                throw new Error('No API key provided');
            }

            // Search with an invalid key
            try {
                const response = await this.search('invalid', 'query', 1);
                if (response.code !== 16) {
                    throw new Error('Unexpected response from known-bad API query.');
                }
            } catch (error) {
                throw new Error(`Error searching with invalid key: ${error.message}`);
            }

            // Search with a valid key
            try {
                const response = await this.search(this.token, 'cat', 1);
                if (response.code === 16) {
                    throw new Error(response.error);
                } else if (response.results.length !== 1) {
                    throw new Error('Unexpected response from known-good API query.');
                }
            } catch (error) {
                throw new Error(`Error searching with valid key: ${error.message}`);
            }
        }

        search(token, query, limit) {
            return new Promise((resolve, reject) => {
                // Form the search url
                const searchUrl = `https://g.tenor.com/v1/search?q=${query}&key=${token}&limit=${limit}`;
            
                // Submit the search
                new Request().get(searchUrl, (error, response) => {
                    if (error) {
                        return reject(new Error(`Error fetching GIFs: ${error.message}`));
                    }
                    try {
                        // Parse the json response
                        const responseJson = JSON.parse(response);
                        resolve(responseJson);
                    } catch (parseError) {
                        reject(new Error(`Error parsing response: ${parseError.message}`));
                    }
                });
            });
        }
    }
}